# image_processing

Description. 
The package image_processing is used to:
	Processing:
		- Histogram matching
		- Structural simularity
		- Resize image
	Utils:
		- Read image
		- Save image
		- Plot image
		- Plot histogram

## Installation

Use the package manager [pip](https://pip.pypa.io/en/stable/) to install package_name

```bash
pip install image_processing
```

## Usage

```python
from package_name.module1_name import file1_name
file1_name.my_function()
```

## Author
Gabrielli Vieira Santos

## License
[MIT](https://choosealicense.com/licenses/mit/)